@@ -120,8 +120,12 @@ cat <<EOF >> "${TEST_DIR}"/tests/integration/cloud-config-azure.ini
 AZURE_CLIENT_ID:${AZURE_CLIENT_ID}
 AZURE_SECRET:${AZURE_SECRET}
 AZURE_SUBSCRIPTION_ID:${AZURE_SUBSCRIPTION_ID}
+AZURE_SUBSCRIPTION_SEC_ID:${AZURE_SUBSCRIPTION_SEC_ID}
 AZURE_TENANT:${AZURE_TENANT}
 RESOURCE_GROUP:${RESOURCE_GROUP}
+AZURE_PRINCIPAL_ID:${AZURE_PRINCIPAL_ID}
+AZURE_MANAGED_BY_TENANT_ID:${AZURE_MANAGED_BY_TENANT_ID}
+AZURE_ROLE_DEFINITION_ID:${AZURE_ROLE_DEFINITION_ID}
 RESOURCE_GROUP_SECONDARY:${RESOURCE_GROUP_SECONDARY}
 EOF
 
