@@ -11,15 +11,24 @@ from ansible.module_utils.basic import env_fallback
 from ansible.module_utils.urls import fetch_url
 from ansible.module_utils._text import to_text
 
-API_URL = 'https://api.cloudscale.ch/v1/'
-
 
 def cloudscale_argument_spec():
     return dict(
-        api_token=dict(fallback=(env_fallback, ['CLOUDSCALE_API_TOKEN']),
-                       no_log=True,
-                       required=True),
-        api_timeout=dict(default=30, type='int'),
+        api_url=dict(
+            type='str',
+            fallback=(env_fallback, ['CLOUDSCALE_API_URL']),
+            default='https://api.cloudscale.ch/v1',
+        ),
+        api_token=dict(
+            type='str',
+            fallback=(env_fallback, ['CLOUDSCALE_API_TOKEN']),
+            no_log=True,
+            required=True,
+        ),
+        api_timeout=dict(
+            type='int',
+            default=30,
+        ),
     )
 
 
@@ -27,10 +36,15 @@ class AnsibleCloudscaleApi(object):
 
     def __init__(self, module):
         self._module = module
+
+        self._api_url = module.params['api_url']
+        if not self._api_url.endswith('/'):
+            self._api_url = self._api_url + '/'
+
         self._auth_header = {'Authorization': 'Bearer %s' % module.params['api_token']}
 
     def _get(self, api_call):
-        resp, info = fetch_url(self._module, API_URL + api_call,
+        resp, info = fetch_url(self._module, self._api_url + api_call,
                                headers=self._auth_header,
                                timeout=self._module.params['api_timeout'])
 
@@ -42,10 +56,10 @@ class AnsibleCloudscaleApi(object):
             self._module.fail_json(msg='Failure while calling the cloudscale.ch API with GET for '
                                        '"%s".' % api_call, fetch_url_info=info)
 
-    def _post_or_patch(self, api_call, method, data):
+    def _post_or_patch(self, api_call, method, data, filter_none=True):
         # This helps with tags when we have the full API resource href to update.
-        if API_URL not in api_call:
-            api_endpoint = API_URL + api_call
+        if self._api_url not in api_call:
+            api_endpoint = self._api_url + api_call
         else:
             api_endpoint = api_call
 
@@ -55,7 +69,7 @@ class AnsibleCloudscaleApi(object):
             # Deepcopy: Duplicate the data object for iteration, because
             # iterating an object and changing it at the same time is insecure
             for k, v in deepcopy(data).items():
-                if v is None:
+                if filter_none and v is None:
                     del data[k]
 
             data = self._module.jsonify(data)
@@ -74,17 +88,23 @@ class AnsibleCloudscaleApi(object):
             return None
         else:
             self._module.fail_json(msg='Failure while calling the cloudscale.ch API with %s for '
-                                       '"%s".' % (method, api_call), fetch_url_info=info)
+                                       '"%s".' % (method, api_endpoint), fetch_url_info=info)
 
     def _post(self, api_call, data=None):
         return self._post_or_patch(api_call, 'POST', data)
 
-    def _patch(self, api_call, data=None):
-        return self._post_or_patch(api_call, 'PATCH', data)
+    def _patch(self, api_call, data=None, filter_none=True):
+        return self._post_or_patch(api_call, 'PATCH', data, filter_none)
 
     def _delete(self, api_call):
+        # api_call might be full href already
+        if self._api_url not in api_call:
+            api_endpoint = self._api_url + api_call
+        else:
+            api_endpoint = api_call
+
         resp, info = fetch_url(self._module,
-                               API_URL + api_call,
+                               api_endpoint,
                                headers=self._auth_header,
                                method='DELETE',
                                timeout=self._module.params['api_timeout'])
@@ -93,7 +113,7 @@ class AnsibleCloudscaleApi(object):
             return None
         else:
             self._module.fail_json(msg='Failure while calling the cloudscale.ch API with DELETE for '
-                                       '"%s".' % api_call, fetch_url_info=info)
+                                       '"%s".' % api_endpoint, fetch_url_info=info)
 
 
 class AnsibleCloudscaleBase(AnsibleCloudscaleApi):
@@ -132,7 +152,17 @@ class AnsibleCloudscaleBase(AnsibleCloudscaleApi):
         # List of params used to update the resource
         self.resource_update_param_keys = resource_update_param_keys or ['name']
 
-    def _init_resource(self):
+        # Resource has no name field but tags, we use a defined tag as name
+        self.use_tag_for_name = False
+        self.resource_name_tag = "ansible_name"
+
+        # Constraint Keys to match when query by name
+        self.query_constraint_keys = []
+
+    def pre_transform(self, resource):
+        return resource
+
+    def init_resource(self):
         return {
             'state': "absent",
             self.resource_key_uuid: self._module.params.get(self.resource_key_uuid) or self._resource_data.get(self.resource_key_uuid),
@@ -141,11 +171,16 @@ class AnsibleCloudscaleBase(AnsibleCloudscaleApi):
 
     def query(self):
         # Initialize
-        self._resource_data = self._init_resource()
+        self._resource_data = self.init_resource()
 
         # Query by UUID
         uuid = self._module.params[self.resource_key_uuid]
         if uuid is not None:
+
+            # network id case
+            if "/" in uuid:
+                uuid = uuid.split("/")[0]
+
             resource = self._get('%s/%s' % (self.resource_name, uuid))
             if resource:
                 self._resource_data = resource
@@ -154,11 +189,25 @@ class AnsibleCloudscaleBase(AnsibleCloudscaleApi):
         # Query by name
         else:
             name = self._module.params[self.resource_key_name]
+
+            # Resource has no name field, we use a defined tag as name
+            if self.use_tag_for_name:
+                resources = self._get('%s?tag:%s=%s' % (self.resource_name, self.resource_name_tag, name))
+            else:
+                resources = self._get('%s' % self.resource_name)
+
             matching = []
-            resources = self._get('%s' % self.resource_name)
             for resource in resources:
-                if resource[self.resource_key_name] == name:
-                    matching.append(resource)
+                if self.use_tag_for_name:
+                    resource[self.resource_key_name] = resource['tags'].get(self.resource_name_tag)
+
+                # Skip resource if constraints is not given e.g. in case of floating_ip the ip_version differs
+                for constraint_key in self.query_constraint_keys:
+                    if resource[constraint_key] != self._module.params[constraint_key]:
+                        break
+                else:
+                    if resource[self.resource_key_name] == name:
+                        matching.append(resource)
 
             # Fail on more than one resource with identical name
             if len(matching) > 1:
@@ -175,9 +224,9 @@ class AnsibleCloudscaleBase(AnsibleCloudscaleApi):
                 self._resource_data = matching[0]
                 self._resource_data['state'] = "present"
 
-        return self._resource_data
+        return self.pre_transform(self._resource_data)
 
-    def create(self, resource):
+    def create(self, resource, data=None):
         # Fail if UUID/ID was provided but the resource was not found on state=present.
         uuid = self._module.params.get(self.resource_key_uuid)
         if uuid is not None:
@@ -187,18 +236,22 @@ class AnsibleCloudscaleBase(AnsibleCloudscaleApi):
 
         self._result['changed'] = True
 
-        data = dict()
+        if not data:
+            data = dict()
+
         for param in self.resource_create_param_keys:
             data[param] = self._module.params.get(param)
 
         self._result['diff']['before'] = deepcopy(resource)
-        self._result['diff']['after'] = deepcopy(data)
+        self._result['diff']['after'] = deepcopy(resource)
+        self._result['diff']['after'].update(deepcopy(data))
         self._result['diff']['after'].update({
             'state': "present",
         })
 
         if not self._module.check_mode:
             resource = self._post(self.resource_name, data)
+            resource = self.pre_transform(resource)
             resource['state'] = "present"
         return resource
 
@@ -214,6 +267,15 @@ class AnsibleCloudscaleBase(AnsibleCloudscaleApi):
 
     def present(self):
         resource = self.query()
+
+        if self.use_tag_for_name:
+            name_tag_value = self._module.params[self.resource_key_name] or resource.get('tags', dict()).get(self.resource_name_tag)
+            if name_tag_value:
+                self._module.params['tags'] = self._module.params['tags'] or dict()
+                self._module.params['tags'].update({
+                    self.resource_name_tag: name_tag_value
+                })
+
         if resource['state'] == "absent":
             resource = self.create(resource)
         else:
@@ -225,10 +287,14 @@ class AnsibleCloudscaleBase(AnsibleCloudscaleApi):
         if resource['state'] != "absent":
             self._result['changed'] = True
             self._result['diff']['before'] = deepcopy(resource)
-            self._result['diff']['after'] = self._init_resource()
+            self._result['diff']['after'] = self.init_resource()
 
             if not self._module.check_mode:
-                self._delete('%s/%s' % (self.resource_name, resource[self.resource_key_uuid]))
+                href = resource.get('href')
+                if not href:
+                    self._module.fail_json(msg='Unable to delete %s, no href found.')
+
+                self._delete(href)
                 resource['state'] = "absent"
         return self.get_result(resource)
 
@@ -237,28 +303,46 @@ class AnsibleCloudscaleBase(AnsibleCloudscaleApi):
         if param is None:
             return False
 
-        if resource and key in resource:
-            if param != resource[key]:
-                self._result['changed'] = True
+        if not resource or key not in resource:
+            return False
 
-                patch_data = {
-                    key: param
-                }
+        is_different = False
 
-                self._result['diff']['before'].update({key: resource[key]})
-                self._result['diff']['after'].update(patch_data)
+        # If it looks like a stub
+        if isinstance(resource[key], dict) and 'href' in resource[key]:
+            uuid = resource[key].get('href', '').split('/')[-1]
+            if param != uuid:
+                is_different = True
 
-                if not self._module.check_mode:
-                    href = resource.get('href')
-                    if not href:
-                        self._module.fail_json(msg='Unable to update %s, no href found.' % key)
+        elif param != resource[key]:
+            is_different = True
 
-                    self._patch(href, patch_data)
-                    return True
+        if is_different:
+            self._result['changed'] = True
+
+            patch_data = {
+                key: param
+            }
+
+            self._result['diff']['before'].update({key: resource[key]})
+            self._result['diff']['after'].update(patch_data)
+
+            if not self._module.check_mode:
+                href = resource.get('href')
+                if not href:
+                    self._module.fail_json(msg='Unable to update %s, no href found.' % key)
+
+                self._patch(href, patch_data)
+                return True
         return False
 
     def get_result(self, resource):
         if resource:
             for k, v in resource.items():
                 self._result[k] = v
+
+            # Transform the name tag to a name field
+            if self.use_tag_for_name:
+                self._result['name'] = self._result.get('tags', dict()).pop(self.resource_name_tag, None)
+
         return self._result
