@@ -77,6 +77,7 @@ options:
               network of the NIC must belong to the VPC specified by vpc_id. A
               maximum of 12 NICs can be attached to an ECS.
         type: list
+        elements: dict
         required: true
         suboptions:
             ip_address:
@@ -150,6 +151,7 @@ options:
         description:
             - Specifies the data disks of ECS instance.
         type: list
+        elements: dict
         required: false
         suboptions:
             volume_id:
@@ -193,6 +195,7 @@ options:
               parameter is left blank, the default security group is bound to
               the ECS by default.
         type: list
+        elements: str
         required: false
     server_metadata:
         description:
