@@ -15,6 +15,7 @@ import re
 import ssl
 import time
 import traceback
+import datetime
 from collections import OrderedDict
 from distutils.version import StrictVersion
 from random import randint
@@ -430,6 +431,36 @@ def gather_vm_facts(content, vm):
     return facts
 
 
+def ansible_date_time_facts(timestamp):
+    # timestamp is a datetime.datetime object
+    date_time_facts = {}
+    if timestamp is None:
+        return date_time_facts
+
+    utctimestamp = timestamp.astimezone(datetime.timezone.utc)
+
+    date_time_facts['year'] = timestamp.strftime('%Y')
+    date_time_facts['month'] = timestamp.strftime('%m')
+    date_time_facts['weekday'] = timestamp.strftime('%A')
+    date_time_facts['weekday_number'] = timestamp.strftime('%w')
+    date_time_facts['weeknumber'] = timestamp.strftime('%W')
+    date_time_facts['day'] = timestamp.strftime('%d')
+    date_time_facts['hour'] = timestamp.strftime('%H')
+    date_time_facts['minute'] = timestamp.strftime('%M')
+    date_time_facts['second'] = timestamp.strftime('%S')
+    date_time_facts['epoch'] = timestamp.strftime('%s')
+    date_time_facts['date'] = timestamp.strftime('%Y-%m-%d')
+    date_time_facts['time'] = timestamp.strftime('%H:%M:%S')
+    date_time_facts['iso8601_micro'] = utctimestamp.strftime("%Y-%m-%dT%H:%M:%S.%fZ")
+    date_time_facts['iso8601'] = utctimestamp.strftime("%Y-%m-%dT%H:%M:%SZ")
+    date_time_facts['iso8601_basic'] = timestamp.strftime("%Y%m%dT%H%M%S%f")
+    date_time_facts['iso8601_basic_short'] = timestamp.strftime("%Y%m%dT%H%M%S")
+    date_time_facts['tz'] = timestamp.strftime("%Z")
+    date_time_facts['tz_offset'] = timestamp.strftime("%z")
+
+    return date_time_facts
+
+
 def deserialize_snapshot_obj(obj):
     return {'id': obj.id,
             'name': obj.name,
@@ -1382,16 +1413,22 @@ class PyVmomi(object):
         return find_folder_by_name(self.content, folder_name=folder_name)
 
     # Datastore cluster
-    def find_datastore_cluster_by_name(self, datastore_cluster_name):
+    def find_datastore_cluster_by_name(self, datastore_cluster_name, datacenter=None):
         """
         Get datastore cluster managed object by name
         Args:
             datastore_cluster_name: Name of datastore cluster
+            datacenter: Managed object of the datacenter
 
         Returns: Datastore cluster managed object if found else None
 
         """
-        data_store_clusters = get_all_objs(self.content, [vim.StoragePod])
+        if datacenter and hasattr(datacenter, 'datastoreFolder'):
+            folder = datacenter.datastoreFolder
+        else:
+            folder = self.content.rootFolder
+
+        data_store_clusters = get_all_objs(self.content, [vim.StoragePod], folder=folder)
         for dsc in data_store_clusters:
             if dsc.name == datastore_cluster_name:
                 return dsc
