@@ -7,25 +7,20 @@
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
-
-ANSIBLE_METADATA = {'metadata_version': '1.1',
-                    'status': ['stableinterface'],
-                    'supported_by': 'certified'}
-
 DOCUMENTATION = r'''
 ---
 module: bigip_asm_policy_manage
 short_description: Manage BIG-IP ASM policies
 description:
-   - Manage BIG-IP ASM policies, create from templates and manage global policy settings.
+   - Manage BIG-IP ASM policies, create from templates, and manage global policy settings.
 version_added: "1.0.0"
 options:
   active:
     description:
-      - If C(yes) will apply and activate existing inactive policy. If C(no), it will
-        deactivate existing active policy. Generally should be C(yes) only in cases where
+      - If C(yes), will apply and activate the existing inactive policy. If C(no), it will
+        deactivate the existing active policy. Generally should be C(yes) only in cases where
         you want to activate new or existing policy.
-      - In TMOS v14 and above deactivating policy will cause it to be detached from any other associated objects,
+      - In TMOS v14 and later, deactivating the policy will cause it to be detached from any other associated objects,
         hence the default option of C(no) has been removed in order to prevent accidental disassociation.
     type: bool
   apply:
@@ -41,11 +36,11 @@ options:
     required: True
   state:
     description:
-      - When C(state) is C(present), and C(template) parameter is provided,
-        new ASM policy is created from template with the given policy C(name).
-      - When C(state) is present and no C(template) parameter is provided
+      - When C(state) is C(present), and the C(template) parameter is provided,
+        a new ASM policy is created from the template with the given policy C(name).
+      - When C(state) is C(present) and no C(template) parameter is provided, a
         new blank ASM policy is created with the given policy C(name).
-      - When C(state) is C(absent), ensures that the policy is removed, even if it is
+      - When C(state) is C(absent), ensures the policy is removed, even if it is
         currently active.
     type: str
     choices:
@@ -54,7 +49,7 @@ options:
     default: present
   template:
     description:
-      - An ASM policy built-in template. If the template does not exist we will raise an error.
+      - An ASM policy built-in template. If the template does not exist, an error is raised.
       - Once the policy has been created, this value cannot change.
       - The C(Comprehensive), C(Drupal), C(Fundamental), C(Joomla),
         C(Vulnerability Assessment Baseline), and C(Wordpress) templates are only available
@@ -163,12 +158,12 @@ EXAMPLES = r'''
 
 RETURN = r'''
 active:
-  description: Set when activating/deactivating ASM policy
+  description: Set when activating/deactivating an ASM policy
   returned: changed
   type: bool
   sample: yes
 apply:
-  description: Set when applying pending changes to ASM policy
+  description: Set when applying pending changes to an ASM policy
   returned: changed when target policy has changes pending
   type: bool
   sample: yes
@@ -178,22 +173,24 @@ state:
   type: str
   sample: absent
 template:
-  description: Name of the built-in ASM policy template
+  description: Name of the built-in ASM policy template.
   returned: changed
   type: str
   sample: OWA Exchange 2007 (https)
 name:
-  description: Name of the ASM policy to be managed/created
+  description: Name of the ASM policy to be managed/created.
   returned: changed
   type: str
   sample: Asm_APP1_Transparent
 '''
 
 import time
+from datetime import datetime
+from distutils.version import LooseVersion
+
 from ansible.module_utils.basic import (
     AnsibleModule, env_fallback
 )
-from distutils.version import LooseVersion
 
 from ..module_utils.bigip import F5RestClient
 from ..module_utils.common import (
@@ -202,6 +199,7 @@ from ..module_utils.common import (
 from ..module_utils.icontrol import (
     module_provisioned, tmos_version
 )
+from ..module_utils.teem import send_teem
 
 
 class Parameters(AnsibleF5Parameters):
@@ -482,6 +480,8 @@ class BaseManager(object):
         self.changes = UsableChanges()
 
     def exec_module(self):
+        start = datetime.now().isoformat()
+        version = tmos_version(self.client)
         changed = False
         result = dict()
         state = self.want.state
@@ -496,6 +496,7 @@ class BaseManager(object):
         result.update(**changes)
         result.update(dict(changed=changed))
         self._announce_deprecations(result)
+        send_teem(start, self.module, version)
         return result
 
     def _announce_deprecations(self, result):
