@@ -7,17 +7,12 @@
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
-
-ANSIBLE_METADATA = {'metadata_version': '1.1',
-                    'status': ['stableinterface'],
-                    'supported_by': 'certified'}
-
 DOCUMENTATION = r'''
 ---
 module: bigip_gtm_virtual_server
 short_description: Manages F5 BIG-IP GTM virtual servers
 description:
-  - Manages F5 BIG-IP GTM virtual servers. A GTM server can have many virtual servers
+  - Manages F5 BIG-IP GTM (now BIG-IP DNS) virtual servers. A GTM server can have many virtual servers
     associated with it. They are arranged in much the same way that pool members are
     to pools.
 version_added: "1.0.0"
@@ -29,7 +24,7 @@ options:
     required: True
   server_name:
     description:
-      - Specifies the name of the server that the virtual server is associated with.
+      - Specifies the name of the server the virtual server is associated with.
     type: str
     required: True
   address:
@@ -48,7 +43,7 @@ options:
   translation_address:
     description:
       - Specifies the translation IP address for the virtual server.
-      - To unset this parameter, provide an empty string (C("")) as a value.
+      - To unset this parameter, use an empty string (C("")) as a value.
       - When creating a new GTM virtual server, if this parameter is not specified, a
         default of C(::) will be used.
     type: str
@@ -61,7 +56,7 @@ options:
     type: str
   availability_requirements:
     description:
-      - Specifies, if you activate more than one health monitor, the number of health
+      - If you activate more than one health monitor, specifies the number of health
         monitors that must receive successful responses in order for the link to be
         considered available.
     type: dict
@@ -69,7 +64,7 @@ options:
       type:
         description:
           - Monitor rule type when C(monitors) is specified.
-          - When creating a new virtual, if this value is not specified, the default of 'all' will be used.
+          - When creating a new virtual, if this value is not specified, the default of C(all) will be used.
         type: str
         required: True
         choices:
@@ -88,7 +83,7 @@ options:
           - Specifies the minimum number of probes that must succeed for this server to be declared up.
           - When creating a new virtual server, if this parameter is specified, then the C(number_of_probers)
             parameter must also be specified.
-          - The value of this parameter should always be B(lower) than, or B(equal to),
+          - The value of this parameter should always be B(lower) than or B(equal to)
             the value of C(number_of_probers).
           - This parameter is only relevant when a C(type) of C(require) is used.
           - This parameter will be ignored if a type of either C(all) or C(at_least) is used.
@@ -96,16 +91,16 @@ options:
       number_of_probers:
         description:
           - Specifies the number of probers that should be used when running probes.
-          - When creating a new virtual server, if this parameter is specified, then the C(number_of_probes)
+          - When creating a new virtual server, if this parameter is specified, the C(number_of_probes)
             parameter must also be specified.
-          - The value of this parameter should always be B(higher) than, or B(equal to),
+          - The value of this parameter should always be B(higher) than or B(equal to)
             the value of C(number_of_probers).
           - This parameter is only relevant when a C(type) of C(require) is used.
           - This parameter will be ignored if a type of either C(all) or C(at_least) is used.
         type: int
   monitors:
     description:
-      - Specifies the health monitors that the system currently uses to monitor this resource.
+      - Specifies the health monitors the system currently uses to monitor this resource.
       - When C(availability_requirements.type) is C(require), you may only have a single monitor in the
         C(monitors) list.
     type: list
@@ -137,7 +132,7 @@ options:
       - When you enable one or more limit settings, the system then uses that data to take servers in and out
         of service.
       - You can define limits for any or all of the limit settings. However, when a server does not meet the resource
-        threshold limit requirement, the system marks the entire server as unavailable and directs load-balancing
+        threshold limit requirement, the system marks the entire server as unavailable and directs load balancing
         traffic to another resource.
       - The limit settings available depend on the type of server.
     type: dict
@@ -159,14 +154,14 @@ options:
         type: bool
       bits_limit:
         description:
-          - Specifies the maximum allowable data throughput rate, in bits per second,
-            for the virtual servers on the server.
+          - Specifies the maximum allowable data throughput rate
+            for the virtual servers on the server, in bits per second.
           - If the network traffic volume exceeds this limit, the system marks the server as unavailable.
         type: int
       packets_limit:
         description:
-          - Specifies the maximum allowable data transfer rate, in packets per second,
-            for the virtual servers on the server.
+          - Specifies the maximum allowable data transfer rate
+            for the virtual servers on the server, in packets per second.
           - If the network traffic volume exceeds this limit, the system marks the server as unavailable.
         type: int
       connections_limit:
@@ -182,7 +177,7 @@ options:
     default: Common
   state:
     description:
-      - When C(present), ensures that the resource exists.
+      - When C(present), ensures the resource exists.
       - When C(absent), ensures the resource is removed.
     type: str
     choices:
@@ -247,7 +242,7 @@ monitors:
   type: list
   sample: ['/Common/monitor1', '/Common/monitor2']
 virtual_server_dependencies:
-  description: The new list of virtual server dependencies for the resource
+  description: The new list of virtual server dependencies for the resource.
   returned: changed
   type: list
   sample: ['/Common/vs1', '/Common/vs2']
@@ -265,25 +260,26 @@ limits:
 
 import os
 import re
+from datetime import datetime
 
 from ansible.module_utils.basic import (
     AnsibleModule, env_fallback
 )
 
-try:
-    from ansible_collections.ansible.netcommon.plugins.module_utils.compat.ipaddress import ip_address
-except ImportError:
-    from ansible.module_utils.compat.ipaddress import ip_address
+from ansible_collections.ansible.netcommon.plugins.module_utils.compat.ipaddress import ip_address
 
 from ..module_utils.bigip import F5RestClient
 from ..module_utils.common import (
     F5ModuleError, AnsibleF5Parameters, transform_name, f5_argument_spec, fq_name
 )
 from ..module_utils.compare import compare_complex_list
-from ..module_utils.icontrol import module_provisioned
+from ..module_utils.icontrol import (
+    module_provisioned, tmos_version
+)
 from ..module_utils.ipaddress import (
     validate_ip_v6_address, is_valid_ip
 )
+from ..module_utils.teem import send_teem
 
 
 class Parameters(AnsibleF5Parameters):
@@ -931,6 +927,8 @@ class ModuleManager(object):
         return False
 
     def exec_module(self):
+        start = datetime.now().isoformat()
+        version = tmos_version(self.client)
         if not module_provisioned(self.client, 'gtm'):
             raise F5ModuleError(
                 "GTM must be provisioned to use this module."
@@ -949,6 +947,7 @@ class ModuleManager(object):
         result.update(**changes)
         result.update(dict(changed=changed))
         self._announce_deprecations(result)
+        send_teem(start, self.module, version)
         return result
 
     def _announce_deprecations(self, result):
