@@ -26,6 +26,10 @@ options:
     - The name of the volume.
     - Volume could be created in a POD with this syntax POD_NAME::VOLUME_NAME.
     - Volume could be created in a volume group with this syntax VG_NAME/VOLUME_NAME.
+    - Multi-volume support available from Purity//FA 6.0.0
+      B(***NOTE***) Manual deletion or eradication of individual volumes created
+      using multi-volume will cause idempotency to fail
+    - Multi-volume support only exists for volume creation
     type: str
     required: true
   target:
@@ -52,6 +56,33 @@ options:
     description:
     - Volume size in M, G, T or P units.
     type: str
+  count:
+    description:
+    - Number of volumes to be created in a multiple volume creation
+    - Only supported from Purity//FA v6.0.0 and higher
+    type: int
+  start:
+    description:
+    - Number at which to start the multiple volume creation index
+    - Only supported from Purity//FA v6.0.0 and higher
+    type: int
+    default: 0
+  digits:
+    description:
+    - Number of digits to use for multiple volume count. This
+      will pad the index number with zeros where necessary
+    - Only supported from Purity//FA v6.0.0 and higher
+    - Range is between 1 and 10
+    type: int
+    default: 1
+  suffix:
+    description:
+    - Suffix string, if required, for multiple volume create
+    - Volume names will be formed as I(<name>#I<suffix>), where
+      I(#) is a placeholder for the volume index
+      See associated descriptions
+    - Only supported from Purity//FA v6.0.0 and higher
+    type: str
   bw_qos:
     description:
     - Bandwidth limit for volume in M or G units.
@@ -96,6 +127,26 @@ EXAMPLES = r'''
     api_token: e31060a7-21fc-e277-6240-25983c6c4592
     state: present
 
+- name: Create new volume named foo in pod bar
+  purefa_volume:
+    name: bar::foo
+    size: 1T
+    fa_url: 10.10.10.2
+    api_token: e31060a7-21fc-e277-6240-25983c6c4592
+    state: present
+
+- name: Create 10 volumes with index starting at 10 but padded with 3 digits
+  purefa_volume:
+    name: foo
+    size: 1T
+    suffix: bar
+    count: 10
+    start: 10
+    digits: 3
+    fa_url: 10.10.10.2
+    api_token: e31060a7-21fc-e277-6240-25983c6c4592
+    state: present
+
 - name: Extend the size of an existing volume named foo
   purefa_volume:
     name: foo
@@ -192,14 +243,23 @@ volume:
             type: int
 '''
 
+HAS_PURESTORAGE = True
+try:
+    from pypureclient import flasharray
+except ImportError:
+    HAS_PURESTORAGE = False
+
+import time
 from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.purestorage.flasharray.plugins.module_utils.purefa import get_system, purefa_argument_spec
+from ansible_collections.purestorage.flasharray.plugins.module_utils.purefa import get_array, get_system, purefa_argument_spec
 
 
 QOS_API_VERSION = "1.14"
 VGROUPS_API_VERSION = "1.13"
 POD_API_VERSION = "1.13"
+AC_QOS_VERSION = "1.16"
 IOPS_API_VERSION = "1.17"
+MULTI_VOLUME_VERSION = "2.2"
 
 
 def human_to_bytes(size):
@@ -208,7 +268,7 @@ def human_to_bytes(size):
        unexpected form.
     """
     bytes = size[:-1]
-    unit = size[-1]
+    unit = size[-1].upper()
     if bytes.isdigit():
         bytes = int(bytes)
         if unit == 'P':
@@ -234,8 +294,10 @@ def human_to_real(iops):
        unexpected form.
     """
     digit = iops[:-1]
-    unit = iops[-1]
-    if digit.isdigit():
+    unit = iops[-1].upper()
+    if unit.isdigit():
+        digit = iops
+    elif digit.isdigit():
         digit = int(digit)
         if unit == 'M':
             digit *= 1000000
@@ -248,6 +310,15 @@ def human_to_real(iops):
     return digit
 
 
+def get_multi_volumes(module, destroyed=False):
+    """Return True is all volumes exist or None"""
+    names = []
+    array = get_array(module)
+    for vol_num in range(module.params['start'], module.params['count'] + module.params['start']):
+        names.append(module.params['name'] + str(vol_num).zfill(module.params['digits']) + module.params['suffix'])
+    return bool(array.get_volumes(names=names, destroyed=destroyed).status_code == 200)
+
+
 def get_volume(module, array):
     """Return Volume or None"""
     try:
@@ -329,65 +400,150 @@ def check_pod(module, array):
 def create_volume(module, array):
     """Create Volume"""
     changed = True
+    volfact = []
     if not module.check_mode:
+        api_version = array._list_available_rest_versions()
         if "/" in module.params['name'] and not check_vgroup(module, array):
             module.fail_json(msg="Failed to create volume {0}. Volume Group does not exist.".format(module.params["name"]))
-        if "::" in module.params['name'] and not check_pod(module, array):
-            module.fail_json(msg="Failed to create volume {0}. Pod does not exist".format(module.params["name"]))
-        volfact = []
-        api_version = array._list_available_rest_versions()
+        if "::" in module.params['name']:
+            if not check_pod(module, array):
+                module.fail_json(msg="Failed to create volume {0}. Pod does not exist".format(module.params["name"]))
+            if module.params['bw_qos'] or module.params['iops_qos']:
+                if AC_QOS_VERSION not in api_version:
+                    module.warn("Pods cannot cannot contain volumes with QoS settings. Ignoring...")
+                    module.params['bw_qos'] = module.params['iops_qos'] = None
+        if not module.params['size']:
+            module.fail_json(msg='Size for a new volume must be specified')
         if module.params['bw_qos'] or module.params['iops_qos']:
-            if module.params['bw_qos'] and QOS_API_VERSION in api_version or module.params['iops_qos'] and IOPS_API_VERSION in api_version:
-                if module.params['bw_qos'] and not module.params['iops_qos']:
-                    if 549755813888 >= int(human_to_bytes(module.params['bw_qos'])) >= 1048576:
-                        try:
-                            volfact = array.create_volume(module.params['name'],
-                                                          module.params['size'],
-                                                          bandwidth_limit=module.params['bw_qos'])
-                        except Exception:
-                            module.fail_json(msg='Volume {0} creation failed.'.format(module.params['name']))
+            if module.params['bw_qos'] and QOS_API_VERSION in api_version:
+                if module.params['iops_qos'] and IOPS_API_VERSION in api_version:
+                    if module.params['bw_qos'] and not module.params['iops_qos']:
+                        if int(human_to_bytes(module.params['bw_qos'])) in range(1048576, 549755813888):
+                            try:
+                                volfact = array.create_volume(module.params['name'],
+                                                              module.params['size'],
+                                                              bandwidth_limit=module.params['bw_qos'])
+                            except Exception:
+                                module.fail_json(msg='Volume {0} creation failed.'.format(module.params['name']))
+                        else:
+                            module.fail_json(msg='Bandwidth QoS value {0} out of range.'.format(module.params['bw_qos']))
+                    elif module.params['iops_qos'] and not module.params['bw_qos']:
+                        if 100000000 >= int(human_to_real(module.params['iops_qos'])) >= 100:
+                            try:
+                                volfact = array.create_volume(module.params['name'],
+                                                              module.params['size'],
+                                                              iops_limit=module.params['iops_qos'])
+                            except Exception:
+                                module.fail_json(msg='Volume {0} creation failed.'.format(module.params['name']))
+                        else:
+                            module.fail_json(msg='IOPs QoS value {0} out of range.'.format(module.params['iops_qos']))
                     else:
-                        module.fail_json(msg='Bandwidth QoS value {0} out of range.'.format(module.params['bw_qos']))
-                elif module.params['iops_qos'] and not module.params['bw_qos']:
-                    if 100000000 >= int(human_to_real(module.params['iops_qos'])) >= 100:
-                        try:
-                            volfact = array.create_volume(module.params['name'],
-                                                          module.params['size'],
-                                                          iops_limit=module.params['iops_qos'])
-                        except Exception:
-                            module.fail_json(msg='Volume {0} creation failed.'.format(module.params['name']))
-                    else:
-                        module.fail_json(msg='IOPs QoS value {0} out of range.'.format(module.params['iops_qos']))
+                        bw_qos_size = int(human_to_bytes(module.params['bw_qos']))
+                        if int(human_to_real(module.params['iops_qos'])) in range(100, 100000000) and bw_qos_size in range(1048576, 549755813888):
+                            try:
+                                volfact = array.create_volume(module.params['name'],
+                                                              module.params['size'],
+                                                              iops_limit=module.params['iops_qos'],
+                                                              bandwidth_limit=module.params['bw_qos'])
+                            except Exception:
+                                module.fail_json(msg='Volume {0} creation failed.'.format(module.params['name']))
+                        else:
+                            module.fail_json(msg='IOPs or Bandwidth QoS value out of range.')
                 else:
-                    bw_qos_size = int(human_to_bytes(module.params['bw_qos']))
-                    if 100000000 >= int(human_to_real(module.params['iops_qos'])) >= 100 and 549755813888 >= bw_qos_size >= 1048576:
+                    if module.params['bw_qos']:
+                        if int(human_to_bytes(module.params['bw_qos'])) in range(1048576, 549755813888):
+                            try:
+                                volfact = array.create_volume(module.params['name'],
+                                                              module.params['size'],
+                                                              bandwidth_limit=module.params['bw_qos'])
+                            except Exception:
+                                module.fail_json(msg='Volume {0} creation failed.'.format(module.params['name']))
+                        else:
+                            module.fail_json(msg='Bandwidth QoS value {0} out of range.'.format(module.params['bw_qos']))
+                    else:
                         try:
-                            volfact = array.create_volume(module.params['name'],
-                                                          module.params['size'],
-                                                          iops_limit=module.params['iops_qos'],
-                                                          bandwidth_limit=module.params['bw_qos'])
+                            volfact = array.create_volume(module.params['name'], module.params['size'])
                         except Exception:
                             module.fail_json(msg='Volume {0} creation failed.'.format(module.params['name']))
-                    else:
-                        module.fail_json(msg='IOPs or Bandwidth QoS value out of range.')
-
         else:
             try:
-                if module.params['size']:
-                    volfact = array.create_volume(module.params['name'], module.params['size'])
-                else:
-                    module.fail_json(msg='Size for a new volume must be specified')
+                volfact = array.create_volume(module.params['name'], module.params['size'])
             except Exception:
                 module.fail_json(msg='Volume {0} creation failed.'.format(module.params['name']))
 
     module.exit_json(changed=changed, volume=volfact)
 
 
+def create_multi_volume(module, array):
+    """Create Volume"""
+    changed = True
+    volfact = {}
+    if not module.check_mode:
+        bw_qos_size = iops_qos_size = 0
+        names = []
+        if "/" in module.params['name'] and not check_vgroup(module, array):
+            module.fail_json(msg="Multi-volume create failed. Volume Group {0} does not exist.".format(module.params["name"].split('/')[0]))
+        if "::" in module.params['name']:
+            if not check_pod(module, array):
+                module.fail_json(msg="Multi-volume create failed. Pod {0} does not exist".format(module.params["name"].split(':')[0]))
+        array = get_array(module)
+        for vol_num in range(module.params['start'], module.params['count'] + module.params['start']):
+            names.append(module.params['name'] + str(vol_num).zfill(module.params['digits']) + module.params['suffix'])
+        if module.params['bw_qos']:
+            bw_qos = int(human_to_bytes(module.params['bw_qos']))
+            if bw_qos in range(1048576, 549755813888):
+                bw_qos_size = bw_qos
+            else:
+                module.fail_json(msg='Bandwidth QoS value out of range.')
+        if module.params['iops_qos']:
+            iops_qos = int(human_to_real(module.params['iops_qos']))
+            if iops_qos in range(100, 100000000):
+                iops_qos_size = iops_qos
+            else:
+                module.fail_json(msg='IOPs QoS value out of range.')
+        if bw_qos_size != 0 and iops_qos_size != 0:
+            vols = flasharray.VolumePost(provisioned=human_to_bytes(module.params['size']),
+                                         qos=flasharray.Qos(bandwidth_limit=bw_qos_size,
+                                                            iops_limit=iops_qos_size),
+                                         subtype='regular')
+        elif bw_qos_size == 0 and iops_qos_size == 0:
+            vols = flasharray.VolumePost(provisioned=human_to_bytes(module.params['size']),
+                                         subtype='regular')
+        elif bw_qos_size == 0 and iops_qos_size != 0:
+            vols = flasharray.VolumePost(provisioned=human_to_bytes(module.params['size']),
+                                         qos=flasharray.Qos(iops_limit=iops_qos_size),
+                                         subtype='regular')
+        elif bw_qos_size != 0 and iops_qos_size == 0:
+            vols = flasharray.VolumePost(provisioned=human_to_bytes(module.params['size']),
+                                         qos=flasharray.Qos(bandwidth_limit=bw_qos_size),
+                                         subtype='regular')
+        res = array.post_volumes(names=names, volume=vols)
+        if res.status_code != 200:
+            module.fail_json(msg='Multi-Volume {0}#{1} creation failed: {2}'.format(module.params['name'],
+                                                                                    module.params['suffix'],
+                                                                                    res.errors[0].message))
+        else:
+            temp = list(res.items)
+            for count in range(0, len(temp)):
+                vol_name = temp[count].name
+                volfact[vol_name] = {
+                    'size': temp[count].provisioned,
+                    'serial': temp[count].serial,
+                    'created': time.strftime('%Y-%m-%d %H:%M:%S', time.localtime(temp[count].created / 1000)),
+                }
+                if bw_qos_size != 0:
+                    volfact[vol_name]['bandwidth_limit'] = temp[count].qos.bandwidth_limit
+                if iops_qos_size != 0:
+                    volfact[vol_name]['iops_limit'] = temp[count].qos.iops_limit
+
+    module.exit_json(changed=changed, volfact=volfact)
+
+
 def copy_from_volume(module, array):
     """Create Volume Clone"""
     changed = True
+    volfact = []
     if not module.check_mode:
-        volfact = []
         tgt = get_target(module, array)
 
         if tgt is None:
@@ -412,9 +568,9 @@ def copy_from_volume(module, array):
 def update_volume(module, array):
     """Update Volume size and/or QoS"""
     changed = True
+    volfact = []
     if not module.check_mode:
         change = False
-        volfact = []
         api_version = array._list_available_rest_versions()
         vol = array.get_volume(module.params['name'])
         vol_qos = array.get_volume(module.params['name'], qos=True)
@@ -424,6 +580,11 @@ def update_volume(module, array):
         if IOPS_API_VERSION in api_version:
             if vol_qos['iops_limit'] is None:
                 vol_qos['iops_limit'] = 0
+        if "::" in module.params['name']:
+            if module.params['bw_qos'] or module.params['iops_qos']:
+                if AC_QOS_VERSION not in api_version:
+                    module.warn("Pods cannot cannot contain volumes with QoS settings. Ignoring...")
+                    module.params['bw_qos'] = module.params['iops_qos'] = None
         if module.params['size']:
             if human_to_bytes(module.params['size']) != vol['size']:
                 if human_to_bytes(module.params['size']) > vol['size']:
@@ -440,7 +601,7 @@ def update_volume(module, array):
                         change = True
                     except Exception:
                         module.fail_json(msg='Volume {0} Bandwidth QoS removal failed.'.format(module.params['name']))
-                elif 549755813888 >= int(human_to_bytes(module.params['bw_qos'])) >= 1048576:
+                elif int(human_to_bytes(module.params['bw_qos'])) in range(1048576, 549755813888):
                     try:
                         volfact = array.set_volume(module.params['name'],
                                                    bandwidth_limit=module.params['bw_qos'])
@@ -457,7 +618,7 @@ def update_volume(module, array):
                         change = True
                     except Exception:
                         module.fail_json(msg='Volume {0} IOPs QoS removal failed.'.format(module.params['name']))
-                elif 100000000 >= int(human_to_real(module.params['iops_qos'])) >= 100:
+                elif int(human_to_real(module.params['iops_qos'])) in range(100, 100000000):
                     try:
                         volfact = array.set_volume(module.params['name'],
                                                    iops_limit=module.params['iops_qos'])
@@ -475,11 +636,11 @@ def update_volume(module, array):
 def rename_volume(module, array):
     """Rename volume within a container, ie pod, vgroup or local array"""
     changed = True
+    volfact = []
     if not module.check_mode:
         changed = False
         pod_name = ''
         vgroup_name = ''
-        volfact = []
         target_name = module.params['rename']
         target_exists = False
         if "::" in module.params['name']:
@@ -524,13 +685,13 @@ def rename_volume(module, array):
 def move_volume(module, array):
     """Move volume between pods, vgroups or local array"""
     changed = True
+    volfact = []
     if not module.check_mode:
         changed = False
         vgroup_exists = False
         pod_exists = False
         pod_name = ''
         vgroup_name = ''
-        volfact = []
         volume_name = module.params['name']
         if "::" in module.params['name']:
             volume_name = module.params["name"].split("::")[1]
@@ -554,22 +715,16 @@ def move_volume(module, array):
                 pod_exists = array.get_pod(module.params['move'])
                 if len(pod_exists['arrays']) > 1:
                     module.fail_json(msg='Volume cannot be moved into a stretched pod')
-                try:
-                    target_exists = array.get_volume(module.params['move'] + "::" + volume_name, pending=True)
-                    module.exit_json(changed=changed)
-                except Exception:
-                    target_exists = False
+                target_exists = bool(array.get_volume(module.params['move'] + "::" + volume_name, pending=True))
             except Exception:
                 pod_exists = False
             try:
                 vgroup_exists = bool(array.get_vgroup(module.params['move']))
-                try:
-                    target_exists = array.get_volume(module.params['move'] + "/" + volume_name, pending=True)
-                    module.exit_json(changed=changed)
-                except Exception:
-                    target_exists = False
+                target_exists = bool(array.get_volume(module.params['move'] + "/" + volume_name, pending=True))
             except Exception:
                 vgroup_exists = False
+            if target_exists:
+                module.fail_json(msg='Volume of same name already exists in move location')
             if pod_exists and vgroup_exists:
                 module.fail_json(msg='Move location {0} matches both a pod and a vgroup. Please rename one of these.'.format(module.params['move']))
             if not pod_exists and not vgroup_exists:
@@ -595,8 +750,8 @@ def move_volume(module, array):
 def delete_volume(module, array):
     """ Delete Volume"""
     changed = True
+    volfact = []
     if not module.check_mode:
-        volfact = []
         try:
             array.destroy_volume(module.params['name'])
             if module.params['eradicate']:
@@ -625,8 +780,8 @@ def eradicate_volume(module, array):
 def recover_volume(module, array):
     """ Recover Deleted Volume"""
     changed = True
+    volfact = []
     if not module.check_mode:
-        volfact = []
         try:
             array.recover_volume(module.params['name'])
         except Exception:
@@ -646,6 +801,10 @@ def main():
         state=dict(type='str', default='present', choices=['absent', 'present']),
         bw_qos=dict(type='str', aliases=['qos']),
         iops_qos=dict(type='str'),
+        count=dict(type='int'),
+        start=dict(type='int', default=0),
+        digits=dict(type='int', default=1),
+        suffix=dict(type='str'),
         size=dict(type='str'),
     ))
 
@@ -664,6 +823,7 @@ def main():
     destroyed = False
     array = get_system(module)
     volume = get_volume(module, array)
+    api_version = array._list_available_rest_versions()
     endpoint = get_endpoint(module.params['name'], array)
 
     if endpoint:
@@ -672,32 +832,52 @@ def main():
     if not volume:
         destroyed = get_destroyed_volume(module.params['name'], array)
     target = get_target(module, array)
-
-    if state == 'present' and not volume and not destroyed and size:
-        create_volume(module, array)
-    elif state == 'present' and volume and (size or bw_qos or iops_qos):
-        update_volume(module, array)
-    elif state == 'present' and volume and module.params['move']:
-        move_volume(module, array)
-    elif state == 'present' and volume and module.params['rename']:
-        rename_volume(module, array)
-    elif state == 'present' and destroyed and not module.params['move'] and not module.params['rename']:
-        recover_volume(module, array)
-    elif state == 'present' and destroyed and module.params['move']:
-        module.fail_json(msg='Volume {0} exists, but in destroyed state'.format(module.params['name']))
-    elif state == 'present' and volume and target:
-        copy_from_volume(module, array)
-    elif state == 'present' and volume and not target:
-        copy_from_volume(module, array)
-    elif state == 'absent' and volume:
-        delete_volume(module, array)
-    elif state == 'absent' and destroyed:
-        eradicate_volume(module, array)
-    elif state == 'present':
-        if not volume and not size:
+    if module.params['count']:
+        if not HAS_PURESTORAGE:
+            module.fail_json(msg='py-pure-client sdk is required to support \'count\' parameter')
+        if MULTI_VOLUME_VERSION not in api_version:
+            module.fail_json(msg='\'count\' parameter is not supported until Purity//FA 6.0.0 or higher')
+        if module.params['digits'] and module.params['digits'] not in range(1, 10):
+            module.fail_json(msg='\'digits\' must be in the range of 1 to 10')
+        if module.params['start'] < 0:
+            module.fail_json(msg='\'start\' must be a positive number')
+        volume = get_multi_volumes(module)
+        if state == 'present' and not volume and size:
+            create_multi_volume(module, array)
+        elif state == 'present' and not volume and not size:
             module.fail_json(msg="Size must be specified to create a new volume")
-    elif state == 'absent' and not volume:
-        module.exit_json(changed=False)
+        elif state == 'absent' and not volume:
+            module.exit_json(changed=False)
+        else:
+            module.warn('Method not yet supported for multi-volume')
+    else:
+        if state == 'present' and not volume and not destroyed and size:
+            create_volume(module, array)
+        elif state == 'present' and volume and (size or bw_qos or iops_qos):
+            update_volume(module, array)
+        elif state == 'present' and not volume and module.params['move']:
+            module.fail_json(msg='Volume {0} cannot be moved - does not exist (maybe deleted)'.format(module.params['name']))
+        elif state == 'present' and volume and module.params['move']:
+            move_volume(module, array)
+        elif state == 'present' and volume and module.params['rename']:
+            rename_volume(module, array)
+        elif state == 'present' and destroyed and not module.params['move'] and not module.params['rename']:
+            recover_volume(module, array)
+        elif state == 'present' and destroyed and module.params['move']:
+            module.fail_json(msg='Volume {0} exists, but in destroyed state'.format(module.params['name']))
+        elif state == 'present' and volume and target:
+            copy_from_volume(module, array)
+        elif state == 'present' and volume and not target:
+            copy_from_volume(module, array)
+        elif state == 'absent' and volume:
+            delete_volume(module, array)
+        elif state == 'absent' and destroyed:
+            eradicate_volume(module, array)
+        elif state == 'present':
+            if not volume and not size:
+                module.fail_json(msg="Size must be specified to create a new volume")
+        elif state == 'absent' and not volume:
+            module.exit_json(changed=False)
 
     module.exit_json(changed=False)
 
